KlumpCheckout class

Constructors

KlumpCheckout()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pay({required BuildContext context, required KlumpCheckoutData data}) Future<KlumpCheckoutResponse?>
Initiate KlumpCheckout and pay using the payment UI
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited