RepaymentDetailsModel class

Inheritance

Constructors

RepaymentDetailsModel({required String? accountNumber, required String? transactionType, required dynamic amount, required dynamic loanAmount, required dynamic downpaymentAmount, required dynamic monthlyRepayment, required dynamic totalRepayment, required dynamic managementFee, required dynamic interest, required dynamic vat, required dynamic insurance, required dynamic tenor, required dynamic installment, required dynamic minimumBalanceRequired, required dynamic repaymentDay, required List<RepaymentScheduleModel>? repaymentSchedules, required dynamic repaymentMetadata})
const
RepaymentDetailsModel.fromJson(Map<String, dynamic> json)
factory

Properties

accountNumber String?
finalinherited
amount → dynamic
finalinherited
downpaymentAmount → dynamic
finalinherited
hashCode int
The hash code for this object.
no setterinherited
installment → dynamic
finalinherited
insurance → dynamic
finalinherited
interest → dynamic
finalinherited
loanAmount → dynamic
finalinherited
managementFee → dynamic
finalinherited
minimumBalanceRequired → dynamic
finalinherited
monthlyRepayment → dynamic
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
repaymentDay → dynamic
finalinherited
repaymentMetadata → dynamic
finalinherited
repaymentSchedules List<RepaymentScheduleModel>?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tenor → dynamic
finalinherited
totalRepayment → dynamic
finalinherited
transactionType String?
finalinherited
vat → dynamic
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited